Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(791)

Unified Diff: runtime/vm/cpu_ia32.cc

Issue 9314053: Revert Dart_PropagateError until I can track down the problems in (Closed) Base URL: http://dart.googlecode.com/svn/branches/bleeding_edge/dart/
Patch Set: Created 8 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « runtime/vm/cpu_arm.cc ('k') | runtime/vm/cpu_x64.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/vm/cpu_ia32.cc
===================================================================
--- runtime/vm/cpu_ia32.cc (revision 3821)
+++ runtime/vm/cpu_ia32.cc (working copy)
@@ -73,16 +73,16 @@
}
-void CPU::JumpToErrorHandler(
+void CPU::JumpToUnhandledExceptionHandler(
uword program_counter,
uword stack_pointer,
uword frame_pointer,
- const Error& error) {
+ const UnhandledException& unhandled_exception_object) {
// The no_gc StackResource is unwound through the tear down of
// stack resources below.
NoGCScope no_gc;
- ASSERT(!error.IsNull());
- RawError* raw_error = error.raw();
+ ASSERT(!unhandled_exception_object.IsNull());
+ RawUnhandledException* unhandled_exception = unhandled_exception_object.raw();
// Prepare for unwinding frames by destroying all the stack resources
// in the previous frames.
@@ -92,11 +92,11 @@
isolate->top_resource()->~StackResource();
}
// Set up the error object as the return value in EAX and continue
// from the invocation stub.
#if defined(TARGET_OS_WINDOWS)
__asm {
- mov eax, raw_error
+ mov eax, unhandled_exception
mov ebx, program_counter
mov ecx, frame_pointer
mov edi, stack_pointer
@@ -105,7 +105,7 @@
jmp ebx
}
#else
- asm volatile("mov %[raw_error], %%eax;"
+ asm volatile("mov %[unhandled_exception], %%eax;"
"mov %[pc], %%ebx;"
"mov %[fp], %%ecx;"
"mov %[sp], %%edi;"
@@ -113,7 +113,7 @@
"mov %%edi, %%esp;"
"jmp *%%ebx;"
:
- : [raw_error] "m" (raw_error),
+ : [unhandled_exception] "m" (unhandled_exception),
[pc] "m" (program_counter),
[sp] "m" (stack_pointer),
[fp] "m" (frame_pointer));
@@ -92,11 +92,11 @@
isolate->top_resource()->~StackResource();
}
- // Set up the error object as the return value in EAX and continue
- // from the invocation stub.
+ // Set up the unhandled exception object as the return value in EAX
+ // and continue from the invocation stub.
#if defined(TARGET_OS_WINDOWS)
__asm {
« no previous file with comments | « runtime/vm/cpu_arm.cc ('k') | runtime/vm/cpu_x64.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698